%{

This function file belongs to the article 'Conversion of a CO-CO2 co-feed with a
porous tubular copper catalyst at low potential'
Authors: Anne Sustronk (1,2) , Nieck E. Benes (1) , Guido Mul (2)
(1) Films in Fluids, Department of Science and Technology, University of 
Twente
(2) Photocatalytic Synthesis Group, Department of Science and Technology, 
University of Twente

This function gives the error sum of squares (SSE or ESS) for a reduced
model and a linear model.
Y = beta2    (Reduced model)
Y = beta1.*X + beta2     (Full linear model)

The smaller the error sum of squares, the better the model describes the
data. The value of the parameters beta1 and beta2 are obtained through
least square estimation. See the Supplementary Information of the paper for
more information

Input values: 
X -> Partial pressure CO
Y -> Production rate

Version date: November 2021

%}

function [outputSSE, outputYfit] = SSE_lin(X,Y)

%% Reduced model
% Y = beta2

Yavg = mean(Y);
YfitRed = Yavg.*ones(1,length(X));

for n = 1:length(X)
    SSE_R(n) = (Y(n) - Yavg)^2;
end

SSE_R= sum(SSE_R);

%% Full linear model
%Y = betaF1Lin*X+betaF2Lin

%Least squares fitting to find beta0 and beta1
%https://nl.mathworks.com/help/curvefit/least-squares-fitting.html#bq_5kr9-2

estim = [0 0];

betaFull = fsolve(@lsqFitFull,estim);
beta1Full = betaFull(1);
beta2Full = betaFull(2);
YfitFull = beta1Full.*X+beta2Full;

for n = 1:length(X)
    SSE_F(n) = (Y(n) - (beta1Full.*X(n)+beta2Full))^2;
end

SSE_F = sum(SSE_F);


%% Define output
outputSSE = [SSE_R SSE_F];
outputYfit = [YfitRed', YfitFull'];

%% Full model least squares regression
    function F = lsqFitFull(betaF)
        F(1) = -2*sum(X.*(Y-(betaF(1).*X+betaF(2))));
        F(2) = -2*sum(Y-(betaF(1).*X+betaF(2)));
    end

end